==> src-foundations-1.0.0-rc.0.tgz: package/typography/index.js <==
function _slicedToArray(arr, i) {
  return _arrayWithHoles(arr) || _iterableToArrayLimit(arr, i) || _unsupportedIterableToArray(arr, i) || _nonIterableRest();
}

function _arrayWithHoles(arr) {
  if (Array.isArray(arr)) return arr;
}

function _iterableToArrayLimit(arr, i) {
  if (typeof Symbol === "undefined" || !(Symbol.iterator in Object(arr))) return;
  var _arr = [];
  var _n = true;
  var _d = false;
  var _e = undefined;

  try {
    for (var _i = arr[Symbol.iterator](), _s; !(_n = (_s = _i.next()).done); _n = true) {
      _arr.push(_s.value);

      if (i && _arr.length === i) break;
    }
  } catch (err) {
    _d = true;
    _e = err;
  } finally {
    try {
      if (!_n && _i["return"] != null) _i["return"]();
    } finally {
      if (_d) throw _e;
    }
  }

  return _arr;
}

function _unsupportedIterableToArray(o, minLen) {
  if (!o) return;
  if (typeof o === "string") return _arrayLikeToArray(o, minLen);
  var n = Object.prototype.toString.call(o).slice(8, -1);
  if (n === "Object" && o.constructor) n = o.constructor.name;
  if (n === "Map" || n === "Set") return Array.from(n);
  if (n === "Arguments" || /^(?:Ui|I)nt(?:8|16|32)(?:Clamped)?Array$/.test(n)) return _arrayLikeToArray(o, minLen);
}

function _arrayLikeToArray(arr, len) {
  if (len == null || len > arr.length) len = arr.length;

  for (var i = 0, arr2 = new Array(len); i < len; i++) arr2[i] = arr[i];

  return arr2;
}

function _nonIterableRest() {
  throw new TypeError("Invalid attempt to destructure non-iterable instance.\nIn order to be iterable, non-array objects must have a [Symbol.iterator]() method.");
}

// The theme file is based on the specification at https://system-ui.com/theme
//
// WARNING!
//
// This is an internal file to be consumed by the src-foundations package only
//
// It contains the lowest level primitives for the entire design system.
// Be very, *very* careful when changing the values in here, changes are likely
// to have a wide-ranging impact across all applications
//
// DANGEROUS CHANGES
//
// The following will almost certainly require further changes to src-foundations.
// They will likely also impact every application that consumes src-foundations
//
// - Updating a value
// - Removing a value
// - Inserting a value into an array
//
// SAFE CHANGES
//
// - Pushing a value onto the end of an array
// - Exporting a new object or array
var fontSizes = [12, 15, 17, 20, 24, 28, 34, 42, 50, 70];
var fonts = {
  titlepiece: "GT Guardian Titlepiece, Georgia, serif",
  headlineSerif: "GH Guardian Headline, Guardian Egyptian Web, Georgia, serif",
  bodySerif: "GuardianTextEgyptian, Guardian Text Egyptian Web, Georgia, serif",
  bodySans: "GuardianTextSans, Guardian Text Sans Web, Helvetica Neue, Helvetica, Arial, Lucida Grande, sans-serif"
};
var lineHeights = [1.15, 1.35, 1.5];
var fontWeights = [300, 400, 500, 700]; // Arrays of colours should have pillar colors first

var titlepieceSizes = {
  small: fontSizes[7],
  //42px
  medium: fontSizes[8],
  //50px
  large: fontSizes[9] //70px

};
var headlineSizes = {
  xxxsmall: fontSizes[2],
  //17px
  xxsmall: fontSizes[3],
  //20px
  xsmall: fontSizes[4],
  //24px
  small: fontSizes[5],
  //28px
  medium: fontSizes[6],
  //34px
  large: fontSizes[7],
  //42px
  xlarge: fontSizes[8] //50px

};
var bodySizes = {
  small: fontSizes[1],
  //15px
  medium: fontSizes[2] //17px

};
var textSansSizes = {
  xsmall: fontSizes[0],
  //12px
  small: fontSizes[1],
  //15px
  medium: fontSizes[2],
  //17px
  large: fontSizes[3],
  //20px
  xlarge: fontSizes[4],
  //24px
  xxlarge: fontSizes[5],
  //28px
  xxxlarge: fontSizes[6] //34px

};
var fontSizeMapping = {
  titlepiece: titlepieceSizes,
  headline: headlineSizes,
  body: bodySizes,
  textSans: textSansSizes
};
var remFontSizes = fontSizes.map(function (fontSize) {
  return fontSize / 16;
});
var remTitlepieceSizes = {
  small: remFontSizes[7],
  //42px
  medium: remFontSizes[8],
  //50px
  large: remFontSizes[9] //70px

};
var remHeadlineSizes = {
  xxxsmall: remFontSizes[2],
  //17px
  xxsmall: remFontSizes[3],
  //20px
  xsmall: remFontSizes[4],
  //24px
  small: remFontSizes[5],
  //28px
  medium: remFontSizes[6],
  //34px
  large: remFontSizes[7],
  //42px
  xlarge: remFontSizes[8] //50px

};
var remBodySizes = {
  small: remFontSizes[1],
  //15px
  medium: remFontSizes[2] //17px

};
var remTextSansSizes = {
  xsmall: remFontSizes[0],
  //12px
  small: remFontSizes[1],
  //15px
  medium: remFontSizes[2],
  //17px
  large: remFontSizes[3],
  //20px
  xlarge: remFontSizes[4],
  //24px
  xxlarge: remFontSizes[5],
  //28px
  xxxlarge: remFontSizes[6] //34px

};
var fontMapping = {
  titlepiece: fonts.titlepiece,
  headline: fonts.headlineSerif,
  body: fonts.bodySerif,
  textSans: fonts.bodySans
};
var lineHeightMapping = {
  tight: lineHeights[0],
  regular: lineHeights[1],
  loose: lineHeights[2]
};
var fontWeightMapping = {
  light: fontWeights[0],
  regular: fontWeights[1],
  medium: fontWeights[2],
  bold: fontWeights[3]
};
var availableFonts = {
  titlepiece: {
    bold: {
      hasItalic: false
    }
  },
  headline: {
    light: {
      hasItalic: true
    },
    medium: {
      hasItalic: true
    },
    bold: {
      hasItalic: false
    }
  },
  body: {
    regular: {
      hasItalic: true
    },
    bold: {
      hasItalic: true
    }
  },
  textSans: {
    regular: {
      hasItalic: true
    },
    bold: {
      hasItalic: false
    }
  }
};
Object.freeze(titlepieceSizes);
Object.freeze(headlineSizes);
Object.freeze(bodySizes);
Object.freeze(textSansSizes);
Object.freeze(remTitlepieceSizes);
Object.freeze(remHeadlineSizes);
Object.freeze(remBodySizes);
Object.freeze(remTextSansSizes);
Object.freeze(fontMapping);
Object.freeze(fontSizeMapping);
Object.freeze(fontWeightMapping);
Object.freeze(lineHeightMapping);
Object.freeze(availableFonts);

function getFontStyle(font, fontStyle) {
  switch (fontStyle) {
    case "italic":
      return font && font.hasItalic ? "italic" : null;

    case "normal":
      return "normal";

    case null:
    default:
      return null;
  }
}

var fs = function fs(category) {
  return function (level, _ref) {
    var lineHeight = _ref.lineHeight,
        fontWeight = _ref.fontWeight,
        fontStyle = _ref.fontStyle,
        unit = _ref.unit;
    var fontFamilyValue = fontMapping[category];
    var fontSizeValue = unit === "px" ? fontSizeMapping[category][level] : "".concat(fontSizeMapping[category][level] / 16, "rem");
    var lineHeightValue = unit === "px" ? "".concat(lineHeightMapping[lineHeight] * fontSizeMapping[category][level], "px") : lineHeightMapping[lineHeight]; // TODO: consider logging an error in development if a requested
    // font is unavailable

    var requestedFont = availableFonts[category][fontWeight];
    var fontWeightValue = requestedFont ? fontWeightMapping[fontWeight] : "";
    var fontStyleValue = getFontStyle(requestedFont, fontStyle);
    return Object.assign({
      fontFamily: fontFamilyValue,
      fontSize: fontSizeValue,
      lineHeight: lineHeightValue
    }, fontWeightValue ? {
      fontWeight: fontWeightValue
    } : {}, fontStyleValue ? {
      fontStyle: fontStyleValue
    } : {});
  };
};

var titlepieceDefaults = {
  lineHeight: "tight",
  fontWeight: "bold",
  fontStyle: null,
  unit: "rem"
};
var titlepieceFs = fs("titlepiece");
var titlepiece = {
  small: function small(options) {
    return titlepieceFs("small", Object.assign({}, titlepieceDefaults, options));
  },
  medium: function medium(options) {
    return titlepieceFs("medium", Object.assign({}, titlepieceDefaults, options));
  },
  large: function large(options) {
    return titlepieceFs("large", Object.assign({}, titlepieceDefaults, options));
  }
};
var headlineDefaults = {
  lineHeight: "tight",
  fontWeight: "medium",
  fontStyle: null,
  unit: "rem"
};
var headlineFs = fs("headline");
var headline = {
  xxxsmall: function xxxsmall(options) {
    return headlineFs("xxxsmall", Object.assign({}, headlineDefaults, options));
  },
  xxsmall: function xxsmall(options) {
    return headlineFs("xxsmall", Object.assign({}, headlineDefaults, options));
  },
  xsmall: function xsmall(options) {
    return headlineFs("xsmall", Object.assign({}, headlineDefaults, options));
  },
  small: function small(options) {
    return headlineFs("small", Object.assign({}, headlineDefaults, options));
  },
  medium: function medium(options) {
    return headlineFs("medium", Object.assign({}, headlineDefaults, options));
  },
  large: function large(options) {
    return headlineFs("large", Object.assign({}, headlineDefaults, options));
  },
  xlarge: function xlarge(options) {
    return headlineFs("xlarge", Object.assign({}, headlineDefaults, options));
  }
};
var bodyDefaults = {
  lineHeight: "loose",
  fontWeight: "regular",
  fontStyle: null,
  unit: "rem"
};
var bodyFs = fs("body");
var body = {
  small: function small(options) {
    return bodyFs("small", Object.assign({}, bodyDefaults, options));
  },
  medium: function medium(options) {
    return bodyFs("medium", Object.assign({}, bodyDefaults, options));
  }
};
var textSansDefaults = {
  lineHeight: "loose",
  fontWeight: "regular",
  fontStyle: null,
  unit: "rem"
};
var textSansFs = fs("textSans");
var textSans = {
  xsmall: function xsmall(options) {
    return textSansFs("xsmall", Object.assign({}, textSansDefaults, options));
  },
  small: function small(options) {
    return textSansFs("small", Object.assign({}, textSansDefaults, options));
  },
  medium: function medium(options) {
    return textSansFs("medium", Object.assign({}, textSansDefaults, options));
  },
  large: function large(options) {
    return textSansFs("large", Object.assign({}, textSansDefaults, options));
  },
  xlarge: function xlarge(options) {
    return textSansFs("xlarge", Object.assign({}, textSansDefaults, options));
  },
  xxlarge: function xxlarge(options) {
    return textSansFs("xxlarge", Object.assign({}, textSansDefaults, options));
  },
  xxxlarge: function xxxlarge(options) {
    return textSansFs("xxxlarge", Object.assign({}, textSansDefaults, options));
  }
};

var objectStylesToString = function objectStylesToString(_ref) {
  var fontFamily = _ref.fontFamily,
      fontSize = _ref.fontSize,
      lineHeight = _ref.lineHeight,
      fontWeight = _ref.fontWeight,
      fontStyle = _ref.fontStyle;
  return "\n\tfont-family: ".concat(fontFamily, ";\n\tfont-size: ").concat(typeof fontSize === "number" ? "".concat(fontSize, "px") : fontSize, ";\n\tline-height: ").concat(lineHeight, ";\n\t").concat(fontWeight ? "font-weight: ".concat(fontWeight) : "", ";\n\t").concat(fontStyle ? "font-style: ".concat(fontStyle) : "", ";\n");
};

var fromEntries = function fromEntries(entries) {
  return entries.reduce(function (acc, _ref) {
    var _ref2 = _slicedToArray(_ref, 2),
        key = _ref2[0],
        value = _ref2[1];

    acc[key] = value;
    return acc;
  }, {});
};

var titlepiece$1 = fromEntries(Object.entries(titlepiece).map(function (_ref3) {
  var _ref4 = _slicedToArray(_ref3, 2),
      key = _ref4[0],
      func = _ref4[1];

  return [key, function (options) {
    return objectStylesToString(func(options));
  }];
}));
var headline$1 = fromEntries(Object.entries(headline).map(function (_ref5) {
  var _ref6 = _slicedToArray(_ref5, 2),
      key = _ref6[0],
      func = _ref6[1];

  return [key, function (options) {
    return objectStylesToString(func(options));
  }];
}));
var body$1 = fromEntries(Object.entries(body).map(function (_ref7) {
  var _ref8 = _slicedToArray(_ref7, 2),
      key = _ref8[0],
      func = _ref8[1];

  return [key, function (options) {
    return objectStylesToString(func(options));
  }];
}));
var textSans$1 = fromEntries(Object.entries(textSans).map(function (_ref9) {
  var _ref10 = _slicedToArray(_ref9, 2),
      key = _ref10[0],
      func = _ref10[1];

  return [key, function (options) {
    return objectStylesToString(func(options));
  }];
}));

export { body$1 as body, bodySizes, fontWeightMapping as fontWeights, fontMapping as fonts, headline$1 as headline, headlineSizes, lineHeightMapping as lineHeights, remBodySizes, remHeadlineSizes, remTextSansSizes, remTitlepieceSizes, textSans$1 as textSans, textSansSizes, titlepiece$1 as titlepiece, titlepieceSizes };

==> src-foundations-1.1.0-rc.5.tgz: package/typography/index.js <==
function _classCallCheck(instance, Constructor) {
  if (!(instance instanceof Constructor)) {
    throw new TypeError("Cannot call a class as a function");
  }
}

function _defineProperties(target, props) {
  for (var i = 0; i < props.length; i++) {
    var descriptor = props[i];
    descriptor.enumerable = descriptor.enumerable || false;
    descriptor.configurable = true;
    if ("value" in descriptor) descriptor.writable = true;
    Object.defineProperty(target, descriptor.key, descriptor);
  }
}

function _createClass(Constructor, protoProps, staticProps) {
  if (protoProps) _defineProperties(Constructor.prototype, protoProps);
  if (staticProps) _defineProperties(Constructor, staticProps);
  return Constructor;
}

function _defineProperty(obj, key, value) {
  if (key in obj) {
    Object.defineProperty(obj, key, {
      value: value,
      enumerable: true,
      configurable: true,
      writable: true
    });
  } else {
    obj[key] = value;
  }

  return obj;
}

function _slicedToArray(arr, i) {
  return _arrayWithHoles(arr) || _iterableToArrayLimit(arr, i) || _unsupportedIterableToArray(arr, i) || _nonIterableRest();
}

function _arrayWithHoles(arr) {
  if (Array.isArray(arr)) return arr;
}

function _iterableToArrayLimit(arr, i) {
  if (typeof Symbol === "undefined" || !(Symbol.iterator in Object(arr))) return;
  var _arr = [];
  var _n = true;
  var _d = false;
  var _e = undefined;

  try {
    for (var _i = arr[Symbol.iterator](), _s; !(_n = (_s = _i.next()).done); _n = true) {
      _arr.push(_s.value);

      if (i && _arr.length === i) break;
    }
  } catch (err) {
    _d = true;
    _e = err;
  } finally {
    try {
      if (!_n && _i["return"] != null) _i["return"]();
    } finally {
      if (_d) throw _e;
    }
  }

  return _arr;
}

function _unsupportedIterableToArray(o, minLen) {
  if (!o) return;
  if (typeof o === "string") return _arrayLikeToArray(o, minLen);
  var n = Object.prototype.toString.call(o).slice(8, -1);
  if (n === "Object" && o.constructor) n = o.constructor.name;
  if (n === "Map" || n === "Set") return Array.from(o);
  if (n === "Arguments" || /^(?:Ui|I)nt(?:8|16|32)(?:Clamped)?Array$/.test(n)) return _arrayLikeToArray(o, minLen);
}

function _arrayLikeToArray(arr, len) {
  if (len == null || len > arr.length) len = arr.length;

  for (var i = 0, arr2 = new Array(len); i < len; i++) arr2[i] = arr[i];

  return arr2;
}

function _nonIterableRest() {
  throw new TypeError("Invalid attempt to destructure non-iterable instance.\nIn order to be iterable, non-array objects must have a [Symbol.iterator]() method.");
}

// The theme file is based on the specification at https://system-ui.com/theme
//
// WARNING!
//
// This is an internal file to be consumed by the src-foundations package only
//
// It contains the lowest level primitives for the entire design system.
// Be very, *very* careful when changing the values in here, changes are likely
// to have a wide-ranging impact across all applications
//
// DANGEROUS CHANGES
//
// The following will almost certainly require further changes to src-foundations.
// They will likely also impact every application that consumes src-foundations
//
// - Updating a value
// - Removing a value
// - Inserting a value into an array
//
// SAFE CHANGES
//
// - Pushing a value onto the end of an array
// - Exporting a new object or array
var fontSizes = [12, 15, 17, 20, 24, 28, 34, 42, 50, 70];
var fonts = {
  titlepiece: "GT Guardian Titlepiece, Georgia, serif",
  headlineSerif: "GH Guardian Headline, Guardian Egyptian Web, Georgia, serif",
  bodySerif: "GuardianTextEgyptian, Guardian Text Egyptian Web, Georgia, serif",
  bodySans: "GuardianTextSans, Guardian Text Sans Web, Helvetica Neue, Helvetica, Arial, Lucida Grande, sans-serif"
};
var lineHeights = [1.15, 1.35, 1.5];
var fontWeights = [300, 400, 500, 700]; // Arrays of colours should have pillar colors first

var TAB_KEY_CODE = 9;
/**
 * Source: Blueprint https://blueprintjs.com/
 * https://github.com/palantir/blueprint/blob/06a186c90758bbdca604ed6d7bf639c3d05b1fa0/packages/core/src/common/interactionMode.ts
 * A nifty little class that maintains event handlers to add a class to the container element
 * when entering "mouse mode" (on a `mousedown` event) and remove it when entering "keyboard mode"
 * (on a `tab` key `keydown` event).
 * Requires @babel/plugin-proposal-class-properties
 */

var InteractionModeEngine = /*#__PURE__*/function () {
  // tslint:disable-next-line:no-constructor-vars
  function InteractionModeEngine(container, className) {
    var _this = this;

    _classCallCheck(this, InteractionModeEngine);

    this.container = container;
    this.className = className;

    _defineProperty(this, "isRunning", false);

    _defineProperty(this, "handleKeyDown", function (e) {
      if (e.which === TAB_KEY_CODE) {
        _this.reset();

        _this.container.addEventListener("mousedown", _this.handleMouseDown);
      }
    });

    _defineProperty(this, "handleMouseDown", function () {
      _this.reset();

      _this.container.classList.add(_this.className);

      _this.container.addEventListener("keydown", _this.handleKeyDown);
    });
  }
  /** Returns whether the engine is currently running. */


  _createClass(InteractionModeEngine, [{
    key: "isActive",
    value: function isActive() {
      return this.isRunning;
    }
    /** Enable behavior which applies the given className when in mouse mode. */

  }, {
    key: "start",
    value: function start() {
      this.container.addEventListener("mousedown", this.handleMouseDown);
      this.isRunning = true;
    }
    /** Disable interaction mode behavior and remove className from container. */

  }, {
    key: "stop",
    value: function stop() {
      this.reset();
      this.isRunning = false;
    }
  }, {
    key: "reset",
    value: function reset() {
      this.container.classList.remove(this.className);
      this.container.removeEventListener("keydown", this.handleKeyDown);
      this.container.removeEventListener("mousedown", this.handleMouseDown);
    }
  }]);

  return InteractionModeEngine;
}();
var FOCUS_DISABLED = "src-focus-disabled";
var focusEngine = new InteractionModeEngine(document.documentElement, FOCUS_DISABLED);

var rootPixelFontSize = 16;
var pxToRem = function pxToRem(px) {
  return px / rootPixelFontSize;
};

var titlepieceSizes = {
  small: fontSizes[7],
  //42px
  medium: fontSizes[8],
  //50px
  large: fontSizes[9] //70px

};
var headlineSizes = {
  xxxsmall: fontSizes[2],
  //17px
  xxsmall: fontSizes[3],
  //20px
  xsmall: fontSizes[4],
  //24px
  small: fontSizes[5],
  //28px
  medium: fontSizes[6],
  //34px
  large: fontSizes[7],
  //42px
  xlarge: fontSizes[8] //50px

};
var bodySizes = {
  small: fontSizes[1],
  //15px
  medium: fontSizes[2] //17px

};
var textSansSizes = {
  xsmall: fontSizes[0],
  //12px
  small: fontSizes[1],
  //15px
  medium: fontSizes[2],
  //17px
  large: fontSizes[3],
  //20px
  xlarge: fontSizes[4],
  //24px
  xxlarge: fontSizes[5],
  //28px
  xxxlarge: fontSizes[6] //34px

};
var fontSizeMapping = {
  titlepiece: titlepieceSizes,
  headline: headlineSizes,
  body: bodySizes,
  textSans: textSansSizes
};
var remFontSizes = fontSizes.map(function (fontSize) {
  return pxToRem(fontSize);
});
var remTitlepieceSizes = {
  small: remFontSizes[7],
  //42px
  medium: remFontSizes[8],
  //50px
  large: remFontSizes[9] //70px

};
var remHeadlineSizes = {
  xxxsmall: remFontSizes[2],
  //17px
  xxsmall: remFontSizes[3],
  //20px
  xsmall: remFontSizes[4],
  //24px
  small: remFontSizes[5],
  //28px
  medium: remFontSizes[6],
  //34px
  large: remFontSizes[7],
  //42px
  xlarge: remFontSizes[8] //50px

};
var remBodySizes = {
  small: remFontSizes[1],
  //15px
  medium: remFontSizes[2] //17px

};
var remTextSansSizes = {
  xsmall: remFontSizes[0],
  //12px
  small: remFontSizes[1],
  //15px
  medium: remFontSizes[2],
  //17px
  large: remFontSizes[3],
  //20px
  xlarge: remFontSizes[4],
  //24px
  xxlarge: remFontSizes[5],
  //28px
  xxxlarge: remFontSizes[6] //34px

};
var remFontSizeMapping = {
  titlepiece: remTitlepieceSizes,
  headline: remHeadlineSizes,
  body: remBodySizes,
  textSans: remTextSansSizes
};
var fontMapping = {
  titlepiece: fonts.titlepiece,
  headline: fonts.headlineSerif,
  body: fonts.bodySerif,
  textSans: fonts.bodySans
};
var lineHeightMapping = {
  tight: lineHeights[0],
  regular: lineHeights[1],
  loose: lineHeights[2]
};
var fontWeightMapping = {
  light: fontWeights[0],
  regular: fontWeights[1],
  medium: fontWeights[2],
  bold: fontWeights[3]
};
var availableFonts = {
  titlepiece: {
    bold: {
      hasItalic: false
    }
  },
  headline: {
    light: {
      hasItalic: true
    },
    medium: {
      hasItalic: true
    },
    bold: {
      hasItalic: false
    }
  },
  body: {
    regular: {
      hasItalic: true
    },
    bold: {
      hasItalic: true
    }
  },
  textSans: {
    regular: {
      hasItalic: true
    },
    bold: {
      hasItalic: false
    }
  }
};
Object.freeze(titlepieceSizes);
Object.freeze(headlineSizes);
Object.freeze(bodySizes);
Object.freeze(textSansSizes);
Object.freeze(remTitlepieceSizes);
Object.freeze(remHeadlineSizes);
Object.freeze(remBodySizes);
Object.freeze(remTextSansSizes);
Object.freeze(fontMapping);
Object.freeze(fontSizeMapping);
Object.freeze(fontWeightMapping);
Object.freeze(lineHeightMapping);
Object.freeze(availableFonts);

function getFontStyle(font, fontStyle) {
  switch (fontStyle) {
    case "italic":
      return font && font.hasItalic ? "italic" : null;

    case "normal":
      return "normal";

    case null:
    default:
      return null;
  }
}

var fs = function fs(category) {
  return function (level, _ref) {
    var lineHeight = _ref.lineHeight,
        fontWeight = _ref.fontWeight,
        fontStyle = _ref.fontStyle,
        unit = _ref.unit;
    var fontFamilyValue = fontMapping[category];
    var fontSizeValue = unit === "px" ? fontSizeMapping[category][level] : "".concat(remFontSizeMapping[category][level], "rem");
    var lineHeightValue = unit === "px" ? // line-height is defined as a unitless value, so we multiply
    // by the element's font-size in px to get the px value
    "".concat(lineHeightMapping[lineHeight] * fontSizeMapping[category][level], "px") : lineHeightMapping[lineHeight]; // TODO: consider logging an error in development if a requested
    // font is unavailable

    var requestedFont = availableFonts[category][fontWeight];
    var fontWeightValue = requestedFont ? fontWeightMapping[fontWeight] : "";
    var fontStyleValue = getFontStyle(requestedFont, fontStyle);
    return Object.assign({
      fontFamily: fontFamilyValue,
      fontSize: fontSizeValue,
      lineHeight: lineHeightValue
    }, fontWeightValue ? {
      fontWeight: fontWeightValue
    } : {}, fontStyleValue ? {
      fontStyle: fontStyleValue
    } : {});
  };
};

var titlepieceDefaults = {
  lineHeight: "tight",
  fontWeight: "bold",
  fontStyle: null,
  unit: "rem"
};
var titlepieceFs = fs("titlepiece");
var titlepiece = {
  small: function small(options) {
    return titlepieceFs("small", Object.assign({}, titlepieceDefaults, options));
  },
  medium: function medium(options) {
    return titlepieceFs("medium", Object.assign({}, titlepieceDefaults, options));
  },
  large: function large(options) {
    return titlepieceFs("large", Object.assign({}, titlepieceDefaults, options));
  }
};
var headlineDefaults = {
  lineHeight: "tight",
  fontWeight: "medium",
  fontStyle: null,
  unit: "rem"
};
var headlineFs = fs("headline");
var headline = {
  xxxsmall: function xxxsmall(options) {
    return headlineFs("xxxsmall", Object.assign({}, headlineDefaults, options));
  },
  xxsmall: function xxsmall(options) {
    return headlineFs("xxsmall", Object.assign({}, headlineDefaults, options));
  },
  xsmall: function xsmall(options) {
    return headlineFs("xsmall", Object.assign({}, headlineDefaults, options));
  },
  small: function small(options) {
    return headlineFs("small", Object.assign({}, headlineDefaults, options));
  },
  medium: function medium(options) {
    return headlineFs("medium", Object.assign({}, headlineDefaults, options));
  },
  large: function large(options) {
    return headlineFs("large", Object.assign({}, headlineDefaults, options));
  },
  xlarge: function xlarge(options) {
    return headlineFs("xlarge", Object.assign({}, headlineDefaults, options));
  }
};
var bodyDefaults = {
  lineHeight: "loose",
  fontWeight: "regular",
  fontStyle: null,
  unit: "rem"
};
var bodyFs = fs("body");
var body = {
  small: function small(options) {
    return bodyFs("small", Object.assign({}, bodyDefaults, options));
  },
  medium: function medium(options) {
    return bodyFs("medium", Object.assign({}, bodyDefaults, options));
  }
};
var textSansDefaults = {
  lineHeight: "loose",
  fontWeight: "regular",
  fontStyle: null,
  unit: "rem"
};
var textSansFs = fs("textSans");
var textSans = {
  xsmall: function xsmall(options) {
    return textSansFs("xsmall", Object.assign({}, textSansDefaults, options));
  },
  small: function small(options) {
    return textSansFs("small", Object.assign({}, textSansDefaults, options));
  },
  medium: function medium(options) {
    return textSansFs("medium", Object.assign({}, textSansDefaults, options));
  },
  large: function large(options) {
    return textSansFs("large", Object.assign({}, textSansDefaults, options));
  },
  xlarge: function xlarge(options) {
    return textSansFs("xlarge", Object.assign({}, textSansDefaults, options));
  },
  xxlarge: function xxlarge(options) {
    return textSansFs("xxlarge", Object.assign({}, textSansDefaults, options));
  },
  xxxlarge: function xxxlarge(options) {
    return textSansFs("xxxlarge", Object.assign({}, textSansDefaults, options));
  }
};

var objectStylesToString = function objectStylesToString(_ref) {
  var fontFamily = _ref.fontFamily,
      fontSize = _ref.fontSize,
      lineHeight = _ref.lineHeight,
      fontWeight = _ref.fontWeight,
      fontStyle = _ref.fontStyle;
  return "\n\tfont-family: ".concat(fontFamily, ";\n\tfont-size: ").concat(typeof fontSize === "number" ? "".concat(fontSize, "px") : fontSize, ";\n\tline-height: ").concat(lineHeight, ";\n\t").concat(fontWeight ? "font-weight: ".concat(fontWeight) : "", ";\n\t").concat(fontStyle ? "font-style: ".concat(fontStyle) : "", ";\n");
};

var fromEntries = function fromEntries(entries) {
  return entries.reduce(function (acc, _ref) {
    var _ref2 = _slicedToArray(_ref, 2),
        key = _ref2[0],
        value = _ref2[1];

    acc[key] = value;
    return acc;
  }, {});
};

var titlepiece$1 = fromEntries(Object.entries(titlepiece).map(function (_ref3) {
  var _ref4 = _slicedToArray(_ref3, 2),
      key = _ref4[0],
      func = _ref4[1];

  return [key, function (options) {
    return objectStylesToString(func(options));
  }];
}));
var headline$1 = fromEntries(Object.entries(headline).map(function (_ref5) {
  var _ref6 = _slicedToArray(_ref5, 2),
      key = _ref6[0],
      func = _ref6[1];

  return [key, function (options) {
    return objectStylesToString(func(options));
  }];
}));
var body$1 = fromEntries(Object.entries(body).map(function (_ref7) {
  var _ref8 = _slicedToArray(_ref7, 2),
      key = _ref8[0],
      func = _ref8[1];

  return [key, function (options) {
    return objectStylesToString(func(options));
  }];
}));
var textSans$1 = fromEntries(Object.entries(textSans).map(function (_ref9) {
  var _ref10 = _slicedToArray(_ref9, 2),
      key = _ref10[0],
      func = _ref10[1];

  return [key, function (options) {
    return objectStylesToString(func(options));
  }];
}));

export { body$1 as body, bodySizes, fontWeightMapping as fontWeights, fontMapping as fonts, headline$1 as headline, headlineSizes, lineHeightMapping as lineHeights, remBodySizes, remHeadlineSizes, remTextSansSizes, remTitlepieceSizes, textSans$1 as textSans, textSansSizes, titlepiece$1 as titlepiece, titlepieceSizes };
